Learn R Programming

ivsacim (version 2.1.0)

treatment_status: This function is to generate a grid of treatment status

Description

This function is to generate a grid of treatment status

Usage

treatment_status(N, K, stime, treatment_init, treatment_shift_time, max_time)

Arguments