Learn R Programming

ivsacim (version 2.1.0)

trt_center: This function is to compute the centralized treatment process given the covariates Z, L at each sorted unique event time

Description

This function is to compute the centralized treatment process given the covariates Z, L at each sorted unique event time

Usage

trt_center(D_status, Z, weights)

Arguments